@@ -147,7 +147,7 @@ MessageViewer::MessageViewer(QWidget *parent)
     : QSplitter(Qt::Vertical, parent)
     , d(std::make_unique<MessageViewer::Private>(this))
 {
-    setObjectName(QStringLiteral("MessageViewerSplitter"));
+    setObjectName(QLatin1StringView("MessageViewerSplitter"));
     setChildrenCollapsible(false);
     setSizes({0});
 
@@ -164,7 +164,7 @@ MessageViewer::MessageViewer(QWidget *parent)
     auto widget = new QWidget(this);
     d->layout = new QVBoxLayout(widget);
     d->layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
-    d->layout->setObjectName(QStringLiteral("PartLayout"));
+    d->layout->setObjectName(QLatin1StringView("PartLayout"));
 
     d->scrollArea = new QScrollArea(this);
     d->scrollArea->setWidget(widget);
@@ -174,6 +174,7 @@ MessageViewer::MessageViewer(QWidget *parent)
     setStretchFactor(2, 2);
 
     d->attachmentView = new AttachmentView(this);
+    d->attachmentView->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::BottomEdge}));
     d->attachmentView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
     addWidget(d->attachmentView);
 
@@ -311,8 +312,16 @@ void MessageViewer::Private::recursiveBuildViewer(PartModel *parts, QVBoxLayout
 
         case PartModel::Types::Error: {
             const auto errorString = parts->data(parts->index(i, 0, parent), PartModel::ErrorString).toString();
-            auto errorWidget = new KMessageWidget(i18n("Error: %1", errorString));
+            auto errorWidget = new KMessageWidget(errorString);
+            errorWidget->setCloseButtonVisible(false);
             errorWidget->setMessageType(KMessageWidget::MessageType::Error);
+            QObject::connect(errorWidget, &KMessageWidget::linkActivated, errorWidget, [this, errorWidget](const QString &link) {
+                QUrl url(link);
+                if (url.path() == QStringLiteral("showCertificate")) {
+                    urlHandler->handleClick(QUrl(link), errorWidget->window()->windowHandle());
+                }
+            });
+            errorWidget->setWordWrap(true);
             layout->addWidget(errorWidget);
             break;
         }
@@ -379,6 +388,12 @@ void MessageViewer::setMessage(const KMime::Message::Ptr message)
         d->selectionChanged();
     });
 
+    connect(d->attachmentView, &QAbstractItemView::doubleClicked, this, [this](const QModelIndex &) {
+        // Since this is only emitted if a valid index is double clicked we can assume
+        // that the first click of the double click set the selection accordingly.
+        d->openSelectedAttachments();
+    });
+
     setUpdatesEnabled(true);
 }
 
